<?php
// $Id$
/**
 * @file
 * www.ag-prime.com
 */


/**
 * Configuration form
 */
function user_history_settings() {
  $fields = user_history_available_fields();
  $track_fields = variable_get('user_history_track_fields', array());
  $form['#title'] = "User History Settings";
  $form['intro'] = array(
          "#type"   => "markup",
          "#value"  => "Select fields to track in profile history.",
  );

  foreach ($fields as $name => $items) {
    $form[$name . '_fieldset'] = array(
            '#type'         => 'fieldset',
            '#title'        => ucwords(preg_replace('/[^a-zA-Z0-9]+/', ' ', $name)),
            '#collapsible'  => TRUE,
            '#collapsed'    => FALSE,
    );
    foreach ($items as $key => $value) {
      $id = $name . ':' . $key;
      $form[$name . '_fieldset'][$id] = array(
              '#type'           => 'checkbox',
              '#title'          => $value,
              '#default_value'  => in_array($id, $track_fields),
      );
    }

  }

  $form['settings'] = array(
          '#type'         => 'fieldset',
          '#title'        => t('Settings'),
          '#collapsible'  => FALSE,
  );
  $form['settings']['user_history_show_collapsed_fieldsets'] = array(
          '#type'          => 'checkbox',
          '#title'         => t('Show history fieldset collapsed by default'),
          '#default_value' => variable_get('user_history_show_collapsed_fieldsets', FALSE),
  );

  $form['#submit'][] = 'user_history_settings_submit';

  return system_settings_form($form);
}

/*
 * Settings submit callback
*/
function user_history_settings_submit($form, &$form_state) {
  //settings form submit
  $track_fields = array();
  foreach ($form_state['values'] as $key => $value) {
    if (in_array($key, array('op', 'submit', 'reset', 'form_build_id', 'form_token', 'form_id'))) continue;
    if ($value) {
      $track_fields[] = $key;
    }
  }
  variable_set('user_history_track_fields', $track_fields);
}

/*
 * Get available fields to track for a user
 * It integrates support for Content Profile and / or Profile modules
*/
function user_history_available_fields() {
  $fields = array();

  // support basic fields
  $fields['User:account']['name'] = t('Username');
  $fields['User:account']['mail'] = t('E-mail address');

  // support Profile
  if (module_exists('profile')) {
    $categories = profile_categories();
    foreach ($categories as $category) {
      $res = _profile_get_fields($category['name']);
      while ($profile_field = db_fetch_object($res)) {
        $fields['User:' . user_history_get_category_name($category['name'])][$profile_field->name] = $profile_field->title;
      }
    }
  }

  // support for Content Profile
  if (module_exists('content_profile')) {
    $content_types = content_profile_get_types('names');
    if (!empty($content_types)) {
      $field_info = _content_type_info();
      foreach ($content_types as $type) {
        $type = user_history_get_category_name($type);
        foreach ($field_info['content types'][$type]['fields'] as $name => $field) {
          $fields['ContentProfile:' . $type][$name] = $field['widget']['label'];
        }
      }
      // locations
      if (isset($field_info['content types'][$type]['extra']['locations'])) {
        $fields['ContentProfile:' . $type]['locations'] = $field_info['content types'][$type]['extra']['locations']['label'];
      }
    }
  }

  return $fields;
}